==> spirit_hub-0.0.1.10.tar.gz: spirit_hub-0.0.1.10/spec/policies/spirit_hub/tagsets_policy_spec.rb <==
# frozen_string_literal: true

require 'rails_helper'

RSpec.describe SpiritHub::TagsetsPolicy do
  let(:admin) { create(:user, roles: ['Administrator']) }
  let(:responsible) { create(:user) }
  let(:reader) { create(:user) }
  let(:writer) { create(:user) }
  let(:accounted_user) { create(:user) }
  let(:other_user) { create(:user) }
  let(:tagset_doc) { create(:tagset_doc, responsible: responsible.id, readers: [reader.id], writers: [writer.id], accounted: [accounted_user.id.to_s]) }
  let(:tagset_directory) { create(:tagset_directory, responsible: responsible.id, readers: [reader.id], writers: [writer.id], accounted: [accounted_user.id.to_s]) }
  let(:all_can_access) { [admin, responsible, writer, reader, accounted_user] }
  let(:all_users) { [admin, responsible, writer, reader, accounted_user, other_user] }

  subject { described_class }

  permissions :index?, :logs?, :doc? do
    it 'permits all_can_access' do
      all_can_access.each do |user|
        expect(subject).to permit(user, tagset_directory)
        expect(subject).to permit(user, tagset_doc)
      end
    end

    it 'denies access to other users' do
      expect(subject).not_to permit(other_user, tagset_directory)
      expect(subject).not_to permit(other_user, tagset_doc)
    end
  end

  permissions :add_doc_form?, :add_doc?, :search_directories?, :add_favorite?, :remove_favorite?, :form? do
    it 'permits all users' do
      all_users.each do |user|
        expect(subject).to permit(user, tagset_directory)
        expect(subject).to permit(user, tagset_doc)
      end
    end
  end

  permissions :share? do
    it 'permits all_can_access' do
      all_can_access.each do |user|
        expect(subject).to permit(user, tagset_directory)
        expect(subject).to permit(user, tagset_doc)
      end
    end
  end

  permissions :request_signature?, :classify?, :evaluate?, :send_to? do
    it 'permits admin, accounted, writers' do
      [admin, accounted_user, writer].each do |user|
        expect(subject).to permit(user, tagset_directory)
        expect(subject).to permit(user, tagset_doc)
      end
    end
  end

  permissions :delete_item?, :bulk_delete?, :inline_edit?, :update_inline? do
    it 'permits admin, writers, responsible' do
      [admin, writer, responsible].each do |user|
        expect(subject).to permit(user, tagset_directory)
        expect(subject).to permit(user, tagset_doc)
      end
    end
  end

  describe SpiritHub::TagsetsPolicy::Scope do
    let(:scope) { Tagset.all }
    let!(:tagset1) { create(:tagset_doc, responsible: responsible.id, readers: [reader.id], writers: [writer.id], accounted: [accounted_user.id.to_s]) }
    let!(:tagset2) { create(:tagset_doc) }
    let!(:tagset_not_in_spirit) { create(:tagset_doc, spirit_hubdoc: false) }

    subject { described_class.new(user, scope).resolve }

    context 'when the user is an admin' do
      let(:user) { admin }

      it 'returns all spirit tagsets' do
        expect(subject).to match_array([tagset1, tagset2])
      end
    end

    it 'when the user is responsible, reader, writer or accounted ' do
      [responsible, reader, writer, accounted_user].each do |user|
        expect(described_class.new(user, scope).resolve).to match_array([tagset1])
      end
    end

    context 'when other_user' do
      let(:user) { other_user }

      it 'returns operations readable by the user' do
        expect(subject).to match_array([])
      end
    end
  end
end

==> spirit_hub-0.1.1.6.tar.gz: spirit_hub-0.1.1.6/spec/policies/spirit_hub/tagsets_policy_spec.rb <==
# frozen_string_literal: true

require 'rails_helper'

RSpec.describe SpiritHub::TagsetsPolicy do
  let(:admin) { create(:user, roles: ['Administrator']) }
  let(:responsible) { create(:user) }
  let(:reader) { create(:user) }
  let(:writer) { create(:user) }
  let(:accounted_user) { create(:user) }
  let(:other_user) { create(:user) }
  let(:tagset_doc) { create(:tagset_doc, responsible: responsible.id, readers: [reader.id], writers: [writer.id], accounted: [accounted_user.id.to_s]) }
  let(:tagset_directory) { create(:tagset_directory, responsible: responsible.id, readers: [reader.id], writers: [writer.id], accounted: [accounted_user.id.to_s]) }
  let(:all_can_access) { [admin, responsible, writer, reader, accounted_user] }
  let(:all_users) { [admin, responsible, writer, reader, accounted_user, other_user] }

  subject { described_class }

  permissions :index?, :journal_entries?, :doc? do
    it 'permits all_can_access' do
      all_can_access.each do |user|
        expect(subject).to permit(user, tagset_directory)
        expect(subject).to permit(user, tagset_doc)
      end
    end

    it 'denies access to other users' do
      expect(subject).not_to permit(other_user, tagset_directory)
      expect(subject).not_to permit(other_user, tagset_doc)
    end
  end

  permissions :add_doc_form?, :add_doc?, :search_directories?, :add_favorite?, :remove_favorite?, :form? do
    it 'permits all users' do
      all_users.each do |user|
        expect(subject).to permit(user, tagset_directory)
        expect(subject).to permit(user, tagset_doc)
      end
    end
  end

  permissions :share? do
    it 'permits all_can_access' do
      all_can_access.each do |user|
        expect(subject).to permit(user, tagset_directory)
        expect(subject).to permit(user, tagset_doc)
      end
    end
  end

  permissions :request_signature?, :classify?, :evaluate?, :send_to? do
    it 'permits admin, accounted, writers' do
      [admin, accounted_user, writer].each do |user|
        expect(subject).to permit(user, tagset_directory)
        expect(subject).to permit(user, tagset_doc)
      end
    end
  end

  permissions :delete_item?, :bulk_delete?, :inline_edit?, :update_inline? do
    it 'permits admin, writers, responsible' do
      [admin, writer, responsible].each do |user|
        expect(subject).to permit(user, tagset_directory)
        expect(subject).to permit(user, tagset_doc)
      end
    end
  end

  describe SpiritHub::TagsetsPolicy::Scope do
    let(:scope) { Tagset.all }
    let!(:tagset1) { create(:tagset_doc, responsible: responsible.id, readers: [reader.id], writers: [writer.id], accounted: [accounted_user.id.to_s]) }
    let!(:tagset2) { create(:tagset_doc) }
    let!(:tagset_not_in_spirit) { create(:tagset_doc, spirit_hubdoc: false) }

    subject { described_class.new(user, scope).resolve }

    context 'when the user is an admin' do
      let(:user) { admin }

      it 'returns all spirit tagsets' do
        expect(subject).to match_array([tagset1, tagset2])
      end
    end

    it 'when the user is responsible, reader, writer or accounted ' do
      [responsible, reader, writer, accounted_user].each do |user|
        expect(described_class.new(user, scope).resolve).to match_array([tagset1])
      end
    end

    context 'when other_user' do
      let(:user) { other_user }

      it 'returns operations readable by the user' do
        expect(subject).to match_array([])
      end
    end
  end
end
